==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/AllEquipment.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentCore"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentBase" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHealthcareAsset" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHealthcareSystem" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHealthcareProperty" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHospitalityFacility" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHospitalityRoom" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHospitalityVehicle" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentCore",
    "equipmentBase",
    "equipmentHealthcareAsset",
    "equipmentHealthcareSystem",
    "equipmentHealthcareProperty",
    "equipmentHospitalityFacility",
    "equipmentHospitalityRoom",
    "equipmentHospitalityVehicle"
})
@XmlRootElement(name = "AllEquipment")
public class AllEquipment {

    @XmlElement(name = "EquipmentCore", required = true)
    protected EquipmentCore equipmentCore;
    @XmlElement(name = "EquipmentBase")
    protected EquipmentBase equipmentBase;
    @XmlElement(name = "EquipmentHealthcareAsset")
    protected EquipmentHealthcareAsset equipmentHealthcareAsset;
    @XmlElement(name = "EquipmentHealthcareSystem")
    protected EquipmentHealthcareSystem equipmentHealthcareSystem;
    @XmlElement(name = "EquipmentHealthcareProperty")
    protected EquipmentHealthcareProperty equipmentHealthcareProperty;
    @XmlElement(name = "EquipmentHospitalityFacility")
    protected EquipmentHospitalityFacility equipmentHospitalityFacility;
    @XmlElement(name = "EquipmentHospitalityRoom")
    protected EquipmentHospitalityRoom equipmentHospitalityRoom;
    @XmlElement(name = "EquipmentHospitalityVehicle")
    protected EquipmentHospitalityVehicle equipmentHospitalityVehicle;

    /**
     * Obtient la valeur de la propriété equipmentCore.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentCore }
     *     
     */
    public EquipmentCore getEquipmentCore() {
        return equipmentCore;
    }

    /**
     * Définit la valeur de la propriété equipmentCore.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentCore }
     *     
     */
    public void setEquipmentCore(EquipmentCore value) {
        this.equipmentCore = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentBase.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentBase }
     *     
     */
    public EquipmentBase getEquipmentBase() {
        return equipmentBase;
    }

    /**
     * Définit la valeur de la propriété equipmentBase.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentBase }
     *     
     */
    public void setEquipmentBase(EquipmentBase value) {
        this.equipmentBase = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentHealthcareAsset.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHealthcareAsset }
     *     
     */
    public EquipmentHealthcareAsset getEquipmentHealthcareAsset() {
        return equipmentHealthcareAsset;
    }

    /**
     * Définit la valeur de la propriété equipmentHealthcareAsset.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHealthcareAsset }
     *     
     */
    public void setEquipmentHealthcareAsset(EquipmentHealthcareAsset value) {
        this.equipmentHealthcareAsset = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentHealthcareSystem.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHealthcareSystem }
     *     
     */
    public EquipmentHealthcareSystem getEquipmentHealthcareSystem() {
        return equipmentHealthcareSystem;
    }

    /**
     * Définit la valeur de la propriété equipmentHealthcareSystem.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHealthcareSystem }
     *     
     */
    public void setEquipmentHealthcareSystem(EquipmentHealthcareSystem value) {
        this.equipmentHealthcareSystem = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentHealthcareProperty.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHealthcareProperty }
     *     
     */
    public EquipmentHealthcareProperty getEquipmentHealthcareProperty() {
        return equipmentHealthcareProperty;
    }

    /**
     * Définit la valeur de la propriété equipmentHealthcareProperty.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHealthcareProperty }
     *     
     */
    public void setEquipmentHealthcareProperty(EquipmentHealthcareProperty value) {
        this.equipmentHealthcareProperty = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentHospitalityFacility.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHospitalityFacility }
     *     
     */
    public EquipmentHospitalityFacility getEquipmentHospitalityFacility() {
        return equipmentHospitalityFacility;
    }

    /**
     * Définit la valeur de la propriété equipmentHospitalityFacility.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHospitalityFacility }
     *     
     */
    public void setEquipmentHospitalityFacility(EquipmentHospitalityFacility value) {
        this.equipmentHospitalityFacility = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentHospitalityRoom.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHospitalityRoom }
     *     
     */
    public EquipmentHospitalityRoom getEquipmentHospitalityRoom() {
        return equipmentHospitalityRoom;
    }

    /**
     * Définit la valeur de la propriété equipmentHospitalityRoom.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHospitalityRoom }
     *     
     */
    public void setEquipmentHospitalityRoom(EquipmentHospitalityRoom value) {
        this.equipmentHospitalityRoom = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentHospitalityVehicle.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHospitalityVehicle }
     *     
     */
    public EquipmentHospitalityVehicle getEquipmentHospitalityVehicle() {
        return equipmentHospitalityVehicle;
    }

    /**
     * Définit la valeur de la propriété equipmentHospitalityVehicle.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHospitalityVehicle }
     *     
     */
    public void setEquipmentHospitalityVehicle(EquipmentHospitalityVehicle value) {
        this.equipmentHospitalityVehicle = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/AllEquipment.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentCore"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentBase" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHealthcareAsset" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHealthcareSystem" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHealthcareProperty" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHospitalityFacility" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHospitalityRoom" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/AssetEquipment_001}EquipmentHospitalityVehicle" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "equipmentCore",
    "equipmentBase",
    "equipmentHealthcareAsset",
    "equipmentHealthcareSystem",
    "equipmentHealthcareProperty",
    "equipmentHospitalityFacility",
    "equipmentHospitalityRoom",
    "equipmentHospitalityVehicle"
})
@XmlRootElement(name = "AllEquipment")
public class AllEquipment {

    @XmlElement(name = "EquipmentCore", required = true)
    protected EquipmentCore equipmentCore;
    @XmlElement(name = "EquipmentBase")
    protected EquipmentBase equipmentBase;
    @XmlElement(name = "EquipmentHealthcareAsset")
    protected EquipmentHealthcareAsset equipmentHealthcareAsset;
    @XmlElement(name = "EquipmentHealthcareSystem")
    protected EquipmentHealthcareSystem equipmentHealthcareSystem;
    @XmlElement(name = "EquipmentHealthcareProperty")
    protected EquipmentHealthcareProperty equipmentHealthcareProperty;
    @XmlElement(name = "EquipmentHospitalityFacility")
    protected EquipmentHospitalityFacility equipmentHospitalityFacility;
    @XmlElement(name = "EquipmentHospitalityRoom")
    protected EquipmentHospitalityRoom equipmentHospitalityRoom;
    @XmlElement(name = "EquipmentHospitalityVehicle")
    protected EquipmentHospitalityVehicle equipmentHospitalityVehicle;

    /**
     * Gets the value of the equipmentCore property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentCore }
     *     
     */
    public EquipmentCore getEquipmentCore() {
        return equipmentCore;
    }

    /**
     * Sets the value of the equipmentCore property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentCore }
     *     
     */
    public void setEquipmentCore(EquipmentCore value) {
        this.equipmentCore = value;
    }

    /**
     * Gets the value of the equipmentBase property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentBase }
     *     
     */
    public EquipmentBase getEquipmentBase() {
        return equipmentBase;
    }

    /**
     * Sets the value of the equipmentBase property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentBase }
     *     
     */
    public void setEquipmentBase(EquipmentBase value) {
        this.equipmentBase = value;
    }

    /**
     * Gets the value of the equipmentHealthcareAsset property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHealthcareAsset }
     *     
     */
    public EquipmentHealthcareAsset getEquipmentHealthcareAsset() {
        return equipmentHealthcareAsset;
    }

    /**
     * Sets the value of the equipmentHealthcareAsset property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHealthcareAsset }
     *     
     */
    public void setEquipmentHealthcareAsset(EquipmentHealthcareAsset value) {
        this.equipmentHealthcareAsset = value;
    }

    /**
     * Gets the value of the equipmentHealthcareSystem property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHealthcareSystem }
     *     
     */
    public EquipmentHealthcareSystem getEquipmentHealthcareSystem() {
        return equipmentHealthcareSystem;
    }

    /**
     * Sets the value of the equipmentHealthcareSystem property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHealthcareSystem }
     *     
     */
    public void setEquipmentHealthcareSystem(EquipmentHealthcareSystem value) {
        this.equipmentHealthcareSystem = value;
    }

    /**
     * Gets the value of the equipmentHealthcareProperty property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHealthcareProperty }
     *     
     */
    public EquipmentHealthcareProperty getEquipmentHealthcareProperty() {
        return equipmentHealthcareProperty;
    }

    /**
     * Sets the value of the equipmentHealthcareProperty property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHealthcareProperty }
     *     
     */
    public void setEquipmentHealthcareProperty(EquipmentHealthcareProperty value) {
        this.equipmentHealthcareProperty = value;
    }

    /**
     * Gets the value of the equipmentHospitalityFacility property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHospitalityFacility }
     *     
     */
    public EquipmentHospitalityFacility getEquipmentHospitalityFacility() {
        return equipmentHospitalityFacility;
    }

    /**
     * Sets the value of the equipmentHospitalityFacility property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHospitalityFacility }
     *     
     */
    public void setEquipmentHospitalityFacility(EquipmentHospitalityFacility value) {
        this.equipmentHospitalityFacility = value;
    }

    /**
     * Gets the value of the equipmentHospitalityRoom property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHospitalityRoom }
     *     
     */
    public EquipmentHospitalityRoom getEquipmentHospitalityRoom() {
        return equipmentHospitalityRoom;
    }

    /**
     * Sets the value of the equipmentHospitalityRoom property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHospitalityRoom }
     *     
     */
    public void setEquipmentHospitalityRoom(EquipmentHospitalityRoom value) {
        this.equipmentHospitalityRoom = value;
    }

    /**
     * Gets the value of the equipmentHospitalityVehicle property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentHospitalityVehicle }
     *     
     */
    public EquipmentHospitalityVehicle getEquipmentHospitalityVehicle() {
        return equipmentHospitalityVehicle;
    }

    /**
     * Sets the value of the equipmentHospitalityVehicle property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentHospitalityVehicle }
     *     
     */
    public void setEquipmentHospitalityVehicle(EquipmentHospitalityVehicle value) {
        this.equipmentHospitalityVehicle = value;
    }

}
